@@ -24,10 +24,6 @@ fn statsig_python_core(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<statsig_user_py::StatsigUserPy>()?;
     m.add_class::<statsig_options_py::StatsigOptionsPy>()?;
     m.add_class::<statsig_options_py::ProxyConfigPy>()?;
-    m.add_class::<statsig_types_py::FeatureGatePy>()?;
-    m.add_class::<statsig_types_py::DynamicConfigPy>()?;
-    m.add_class::<statsig_types_py::ExperimentPy>()?;
-    m.add_class::<statsig_types_py::LayerPy>()?;
     m.add_class::<statsig_types_py::FeatureGateEvaluationOptionsPy>()?;
     m.add_class::<statsig_types_py::ExperimentEvaluationOptionsPy>()?;
     m.add_class::<statsig_types_py::DynamicConfigEvaluationOptionsPy>()?;
@@ -35,7 +31,6 @@ fn statsig_python_core(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<statsig_types_py::ParameterStoreEvaluationOptionsPy>()?;
     m.add_class::<statsig_types_py::InitializeDetailsPy>()?;
     m.add_class::<statsig_types_py::FailureDetailsPy>()?;
-    m.add_class::<statsig_types_py::EvaluationDetailsPy>()?;
     m.add_class::<observability_client_base_py::ObservabilityClientBasePy>()?;
     m.add_class::<data_store_base_py::DataStoreBasePy>()?;
     m.add_class::<statsig_persistent_storage_override_adapter_py::PersistentStorageBasePy>()?;
