@@ -16,12 +16,12 @@ use crate::{
     },
     interned_string::InternedString,
     specs_response::explicit_params::ExplicitParameters,
-    statsig_types_raw::PartialLayerRaw,
     user::{StatsigUserInternal, StatsigUserLoggable},
     EvaluationDetails, SecondaryExposure,
 };
 
 use super::queued_event::{EnqueueOperation, QueuedEvent, QueuedExposure};
+use crate::event_logging::statsig_event::string_metadata_to_value_metadata;
 
 // Flow:
 // IN(EVAL) |> EnqueueOp [sampling]> QueuedEvent [bg thread]> StatsigEventInternal |> OUT(LOGGED)
@@ -165,46 +165,6 @@ impl<'a> EnqueueExposureOp<'a> {
         op
     }
 
-    pub(crate) fn layer_param_exposure_from_partial_raw(
-        parameter_name: InternedString,
-        trigger: ExposureTrigger,
-        partial_raw: PartialLayerRaw,
-    ) -> Self {
-        let version = partial_raw.details.version;
-        let user = UserLoggableOrInternal::Loggable(partial_raw.user);
-
-        let mut rule_id = partial_raw
-            .parameter_rule_ids
-            .as_ref()
-            .and_then(|ids| ids.get(&parameter_name));
-
-        if rule_id.is_none() {
-            rule_id = partial_raw.rule_id.as_ref();
-        }
-
-        let data = ExposureData {
-            event_name: LAYER_EXPOSURE_EVENT_NAME,
-            spec_name: partial_raw.name,
-            rule_id: rule_id.cloned(),
-            exposure_time: Utc::now().timestamp_millis() as u64,
-            trigger,
-            evaluation_details: partial_raw.details,
-            secondary_exposures: partial_raw.secondary_exposures,
-            undelegated_secondary_exposures: partial_raw.undelegated_secondary_exposures,
-            version,
-            override_spec_name: None,
-            rule_passed: None,
-            exposure_info: None,
-            parameter_name: Some(parameter_name),
-            explicit_params: partial_raw.explicit_parameters,
-            allocated_experiment: partial_raw.allocated_experiment_name,
-            is_user_in_experiment: None,
-            gate_value: None,
-        };
-
-        Self { user, data }
-    }
-
     fn new(
         event_name: &'static str,
         user: UserLoggableOrInternal<'a>,
@@ -252,6 +212,49 @@ impl<'a> EnqueueExposureOp<'a> {
     }
 }
 
+#[cfg(feature = "ffi-support")]
+impl<'a> EnqueueExposureOp<'a> {
+    pub(crate) fn layer_param_exposure_from_partial_raw(
+        parameter_name: InternedString,
+        trigger: ExposureTrigger,
+        partial_raw: crate::statsig_types_raw::PartialLayerRaw,
+    ) -> Self {
+        let version = partial_raw.details.version;
+        let user = UserLoggableOrInternal::Loggable(partial_raw.user);
+
+        let mut rule_id = partial_raw
+            .parameter_rule_ids
+            .as_ref()
+            .and_then(|ids| ids.get(&parameter_name));
+
+        if rule_id.is_none() {
+            rule_id = partial_raw.rule_id.as_ref();
+        }
+
+        let data = ExposureData {
+            event_name: LAYER_EXPOSURE_EVENT_NAME,
+            spec_name: partial_raw.name,
+            rule_id: rule_id.cloned(),
+            exposure_time: Utc::now().timestamp_millis() as u64,
+            trigger,
+            evaluation_details: partial_raw.details,
+            secondary_exposures: partial_raw.secondary_exposures,
+            undelegated_secondary_exposures: partial_raw.undelegated_secondary_exposures,
+            version,
+            override_spec_name: None,
+            rule_passed: None,
+            exposure_info: None,
+            parameter_name: Some(parameter_name),
+            explicit_params: partial_raw.explicit_parameters,
+            allocated_experiment: partial_raw.allocated_experiment_name,
+            is_user_in_experiment: None,
+            gate_value: None,
+        };
+
+        Self { user, data }
+    }
+}
+
 impl EnqueueOperation for EnqueueExposureOp<'_> {
     fn as_exposure(&self) -> Option<&impl QueuedExposure<'_>> {
         Some(self)
@@ -344,7 +347,7 @@ impl QueuedExposureEvent {
         let event = StatsigEvent {
             event_name: data.event_name.into(),
             value: None,
-            metadata: Some(builder.build()),
+            metadata: Some(string_metadata_to_value_metadata(builder.build())),
             statsig_metadata: Some(statsig_metadata),
         };
 
