@@ -1,5 +1,10 @@
 #[must_use]
 pub fn djb2(input: &str) -> String {
+    djb2_number(input).to_string()
+}
+
+#[must_use]
+pub fn djb2_number(input: &str) -> i64 {
     let mut hash: i64 = 0;
 
     for c in input.chars() {
@@ -9,5 +14,5 @@ pub fn djb2(input: &str) -> String {
     // Convert to unsigned 32-bit integer
     hash &= 0xFFFF_FFFF;
 
-    hash.to_string()
+    hash
 }
