@@ -3,10 +3,7 @@ use std::sync::Arc;
 use chrono::Utc;
 
 use crate::{
-    evaluation::{
-        evaluation_types::{BaseEvaluation, ExperimentEvaluation, LayerEvaluation},
-        evaluator_result::EvaluatorResult,
-    },
+    evaluation::evaluation_types::{BaseEvaluation, ExperimentEvaluation, LayerEvaluation},
     get_persistent_storage_key,
     interned_string::InternedString,
     log_d, log_error_to_statsig_and_console, make_sticky_value_from_experiment,
@@ -20,12 +17,16 @@ use crate::{
     PersistentStorage, SpecStore, StatsigErr, StickyValues,
 };
 
+#[cfg(feature = "ffi-support")]
+use crate::evaluation::evaluator_result::EvaluatorResult;
+
 pub struct PersistentValuesManager {
     pub persistent_storage: Arc<dyn PersistentStorage>,
 }
 
 const TAG: &str = "PersistentValuesManager";
 
+#[cfg(feature = "ffi-support")]
 impl PersistentValuesManager {
     pub fn try_apply_sticky_value_to_raw_layer<'a>(
         manager: &'a Option<Arc<PersistentValuesManager>>,
@@ -72,70 +73,6 @@ impl PersistentValuesManager {
         (Some(result), details)
     }
 
-    fn try_apply_sticky_value_to_raw_layer_impl<'a>(
-        &self,
-        user: &'a StatsigUserInternal,
-        options: &'a LayerEvaluationOptions,
-        spec_store_data: &'a SpecStoreData,
-        curr_details: EvaluationDetails,
-        curr_result: EvaluatorResult,
-    ) -> (EvaluatorResult, EvaluationDetails) {
-        let id_type = match &curr_result.id_type {
-            Some(id_type) => id_type,
-            None => {
-                return (curr_result, curr_details);
-            }
-        };
-
-        let config_name = match &curr_result.name {
-            Some(name) => name,
-            None => {
-                return (curr_result, curr_details);
-            }
-        };
-
-        let storage_key = match get_persistent_storage_key(user.user_ref, id_type.as_str()) {
-            Some(key) => key,
-            None => {
-                return (curr_result, curr_details);
-            }
-        };
-
-        let sticky_value = options
-            .user_persisted_values
-            .as_ref()
-            .and_then(|values| values.get(config_name.as_str()));
-
-        let is_experiment_active = self.get_sticky_aware_is_experiment_active(
-            curr_result.is_experiment_active,
-            spec_store_data,
-            sticky_value,
-        );
-
-        // Exit Early: Caller does not want sticky, or experiment is not active
-        if options.user_persisted_values.is_none() || !is_experiment_active {
-            self.delete_sticky_value(&storage_key, config_name);
-            return (curr_result, curr_details);
-        }
-
-        // Exit Early: Found a Sticky Value
-        if let Some(found) = sticky_value {
-            let sticky_details = make_evaluation_details_from_sticky_value(found);
-            let sticky_result = make_evaluation_result_from_sticky_value(curr_result, found);
-            return (sticky_result, sticky_details);
-        }
-
-        if curr_result.is_experiment_active && curr_result.is_experiment_group {
-            let new_sticky_value =
-                make_sticky_value_from_evaluation_result(&curr_result, curr_details.lcut);
-
-            self.persistent_storage
-                .save(&storage_key, config_name, new_sticky_value);
-        }
-
-        (curr_result, curr_details)
-    }
-
     pub fn try_apply_sticky_value_to_raw_experiment<'a>(
         manager: &'a Option<Arc<PersistentValuesManager>>,
         user: &'a StatsigUserInternal,
@@ -204,14 +141,14 @@ impl PersistentValuesManager {
 
         // Exit Early: Found a Sticky Value
         if let Some(found) = sticky_value {
-            let sticky_details = make_evaluation_details_from_sticky_value(found);
-            let sticky_result = make_evaluation_result_from_sticky_value(curr_result, found);
+            let sticky_details = Self::make_evaluation_details_from_sticky_value(found);
+            let sticky_result = Self::make_evaluation_result_from_sticky_value(curr_result, found);
             return (sticky_result, sticky_details);
         }
 
         if curr_result.is_experiment_active && curr_result.is_experiment_group {
             let new_sticky_value =
-                make_sticky_value_from_evaluation_result(&curr_result, curr_details.lcut);
+                Self::make_sticky_value_from_evaluation_result(&curr_result, curr_details.lcut);
 
             self.persistent_storage
                 .save(&storage_key, config_name, new_sticky_value);
@@ -220,6 +157,138 @@ impl PersistentValuesManager {
         (curr_result, curr_details)
     }
 
+    fn try_apply_sticky_value_to_raw_layer_impl<'a>(
+        &self,
+        user: &'a StatsigUserInternal,
+        options: &'a LayerEvaluationOptions,
+        spec_store_data: &'a SpecStoreData,
+        curr_details: EvaluationDetails,
+        curr_result: EvaluatorResult,
+    ) -> (EvaluatorResult, EvaluationDetails) {
+        let id_type = match &curr_result.id_type {
+            Some(id_type) => id_type,
+            None => {
+                return (curr_result, curr_details);
+            }
+        };
+
+        let config_name = match &curr_result.name {
+            Some(name) => name,
+            None => {
+                return (curr_result, curr_details);
+            }
+        };
+
+        let storage_key = match get_persistent_storage_key(user.user_ref, id_type.as_str()) {
+            Some(key) => key,
+            None => {
+                return (curr_result, curr_details);
+            }
+        };
+
+        let sticky_value = options
+            .user_persisted_values
+            .as_ref()
+            .and_then(|values| values.get(config_name.as_str()));
+
+        let is_experiment_active = self.get_sticky_aware_is_experiment_active(
+            curr_result.is_experiment_active,
+            spec_store_data,
+            sticky_value,
+        );
+
+        // Exit Early: Caller does not want sticky, or experiment is not active
+        if options.user_persisted_values.is_none() || !is_experiment_active {
+            self.delete_sticky_value(&storage_key, config_name);
+            return (curr_result, curr_details);
+        }
+
+        // Exit Early: Found a Sticky Value
+        if let Some(found) = sticky_value {
+            let sticky_details = Self::make_evaluation_details_from_sticky_value(found);
+            let sticky_result = Self::make_evaluation_result_from_sticky_value(curr_result, found);
+            return (sticky_result, sticky_details);
+        }
+
+        if curr_result.is_experiment_active && curr_result.is_experiment_group {
+            let new_sticky_value =
+                Self::make_sticky_value_from_evaluation_result(&curr_result, curr_details.lcut);
+
+            self.persistent_storage
+                .save(&storage_key, config_name, new_sticky_value);
+        }
+
+        (curr_result, curr_details)
+    }
+
+    // -------------------------------------------------------------------------- [ Raw Experiment/Layer Helpers ]
+
+    fn make_evaluation_details_from_sticky_value(sticky_value: &StickyValues) -> EvaluationDetails {
+        EvaluationDetails {
+            reason: "Persisted".to_owned(),
+            lcut: sticky_value.time,
+            received_at: Some(Utc::now().timestamp_millis() as u64),
+            version: sticky_value.config_version,
+        }
+    }
+
+    fn make_evaluation_result_from_sticky_value(
+        curr_result: EvaluatorResult,
+        sticky_value: &StickyValues,
+    ) -> EvaluatorResult {
+        EvaluatorResult {
+            // transfer from current
+            name: curr_result.name,
+            id_type: curr_result.id_type,
+            bool_value: sticky_value.value,
+
+            // clone from sticky
+            rule_id: sticky_value.rule_id.clone(),
+            group_name: sticky_value.group_name.clone(),
+            json_value: sticky_value.json_value.clone(),
+            version: sticky_value.config_version,
+            config_delegate: sticky_value.config_delegate.clone(),
+            explicit_parameters: sticky_value.explicit_parameters.clone(),
+            secondary_exposures: sticky_value.secondary_exposures.clone(),
+            undelegated_secondary_exposures: sticky_value.undelegated_secondary_exposures.clone(),
+
+            // these are always true for sticky values
+            is_experiment_active: true,
+            is_experiment_group: true,
+
+            // Not yet consumed by raw logic
+            unsupported: false,
+            is_in_layer: false,
+            rule_id_suffix: None,
+            override_reason: None,
+            sampling_rate: None,
+            forward_all_exposures: None,
+            override_config_name: None,
+            has_seen_analytical_gates: None,
+            parameter_rule_ids: None,
+        }
+    }
+
+    fn make_sticky_value_from_evaluation_result(
+        curr_result: &EvaluatorResult,
+        lcut: Option<u64>,
+    ) -> StickyValues {
+        StickyValues {
+            value: curr_result.bool_value,
+            json_value: curr_result.json_value.clone(),
+            rule_id: curr_result.rule_id.clone(),
+            group_name: curr_result.group_name.clone(),
+            secondary_exposures: curr_result.secondary_exposures.clone(),
+            undelegated_secondary_exposures: curr_result.undelegated_secondary_exposures.clone(),
+            config_delegate: curr_result.config_delegate.clone(),
+            explicit_parameters: curr_result.explicit_parameters.clone(),
+            time: lcut,
+            config_version: curr_result.version,
+        }
+    }
+}
+
+impl PersistentValuesManager {
     pub fn try_apply_sticky_value_to_experiment<'a>(
         manager: &'a Option<Arc<PersistentValuesManager>>,
         user: &'a StatsigUserInternal,
@@ -409,72 +478,6 @@ impl PersistentValuesManager {
     }
 }
 
-// -------------------------------------------------------------------------- [ Raw Experiment/Layer Helpers ]
-
-fn make_evaluation_details_from_sticky_value(sticky_value: &StickyValues) -> EvaluationDetails {
-    EvaluationDetails {
-        reason: "Persisted".to_owned(),
-        lcut: sticky_value.time,
-        received_at: Some(Utc::now().timestamp_millis() as u64),
-        version: sticky_value.config_version,
-    }
-}
-
-fn make_evaluation_result_from_sticky_value(
-    curr_result: EvaluatorResult,
-    sticky_value: &StickyValues,
-) -> EvaluatorResult {
-    EvaluatorResult {
-        // transfer from current
-        name: curr_result.name,
-        id_type: curr_result.id_type,
-        bool_value: sticky_value.value,
-
-        // clone from sticky
-        rule_id: sticky_value.rule_id.clone(),
-        group_name: sticky_value.group_name.clone(),
-        json_value: sticky_value.json_value.clone(),
-        version: sticky_value.config_version,
-        config_delegate: sticky_value.config_delegate.clone(),
-        explicit_parameters: sticky_value.explicit_parameters.clone(),
-        secondary_exposures: sticky_value.secondary_exposures.clone(),
-        undelegated_secondary_exposures: sticky_value.undelegated_secondary_exposures.clone(),
-
-        // these are always true for sticky values
-        is_experiment_active: true,
-        is_experiment_group: true,
-
-        // Not yet consumed by raw logic
-        unsupported: false,
-        is_in_layer: false,
-        rule_id_suffix: None,
-        override_reason: None,
-        sampling_rate: None,
-        forward_all_exposures: None,
-        override_config_name: None,
-        has_seen_analytical_gates: None,
-        parameter_rule_ids: None,
-    }
-}
-
-fn make_sticky_value_from_evaluation_result(
-    curr_result: &EvaluatorResult,
-    lcut: Option<u64>,
-) -> StickyValues {
-    StickyValues {
-        value: curr_result.bool_value,
-        json_value: curr_result.json_value.clone(),
-        rule_id: curr_result.rule_id.clone(),
-        group_name: curr_result.group_name.clone(),
-        secondary_exposures: curr_result.secondary_exposures.clone(),
-        undelegated_secondary_exposures: curr_result.undelegated_secondary_exposures.clone(),
-        config_delegate: curr_result.config_delegate.clone(),
-        explicit_parameters: curr_result.explicit_parameters.clone(),
-        time: lcut,
-        config_version: curr_result.version,
-    }
-}
-
 // -------------------------------------------------------------------------- [ Experiment Helpers ]
 
 fn make_experiment_from_sticky_value(
